# Version: 1.6.4

## Features

* [#84](https://github.com/Metron-Project/metron-tagger/pull/84): Find duplicate pages (Here's
  a [blog](https://metron-project.github.io/blog/october-2023-update) entry about the feature)

## Maintenance

* [#91](https://github.com/Metron-Project/metron-tagger/pull/91): Update Poetry
* [#90](https://github.com/Metron-Project/metron-tagger/pull/90): Use Ruff for formatting
* [#89](https://github.com/Metron-Project/metron-tagger/pull/89): Add ChangeLog GitHub action
* [#88](https://github.com/Metron-Project/metron-tagger/pull/88): Refactor filesorter.py
